@@ -6,6 +6,7 @@ import logging
 from typing import Any, Callable, Dict, List, Optional, Union
 import warnings
 
+from aporia.core.types.field import FieldSchema
 from aporia.model import Model
 from .api.create_model_version import run_create_model_version_query
 from .config import Config
@@ -214,9 +215,9 @@ def create_model_version(
     model_id: str,
     model_version: str,
     model_type: str,
-    features: Dict[str, str],
-    predictions: Dict[str, str],
-    raw_inputs: Optional[Dict[str, str]] = None,
+    features: Dict[str, Union[str, FieldSchema]],
+    predictions: Dict[str, Union[str, FieldSchema]],
+    raw_inputs: Optional[Dict[str, Union[str, FieldSchema]]] = None,
     metrics: Optional[Dict[str, str]] = None,
     model_data_type: Optional[str] = None,
     labels: Optional[List[str]] = None,
