@@ -1,8 +1,10 @@
 from datetime import datetime
 from enum import Enum
-from typing import Union
+from typing import Any, Dict, List, Union
 
-FieldValue = Union[float, int, str, bool, datetime]
+FieldValue = Union[float, int, str, bool, datetime, List[int]]
+
+FieldSchema = Dict[str, Any]
 
 
 class FieldType(Enum):
@@ -16,6 +18,7 @@ class FieldType(Enum):
     VECTOR = "vector"
     TEXT = "text"
     DICT = "dict"
+    TENSOR = "tensor"
 
 
 class FieldCategory(Enum):
