@@ -36,7 +36,7 @@ def generate_features_schema_from_shape(features_shape: Tuple) -> OrderedDict:
         OrderedDict: The object to pass to features in the version schema.
     """
     features_schema = OrderedDict()
-    for i in range(np.prod(features_shape)):
+    for i in range(int(np.prod(features_shape))):
         features_schema[f"X{i}"] = FieldType.NUMERIC.value
 
     return features_schema
