@@ -1,69 +1,9 @@
-from abc import ABC, abstractmethod
 from typing import Any, Dict, Optional
 
 from aporia.core.http_client import HttpClient
+from aporia.core.types.data_source import DataSource
 
-
-class DataSource(ABC):
-    """General data source representation."""
-
-    @property
-    @abstractmethod
-    def _type(self) -> str:
-        raise ValueError("Data source type is not defined")
-
-    @property
-    @abstractmethod
-    def _config(self) -> Dict[str, Any]:
-        raise ValueError("Data source config is not defined")
-
-
-class SparkDataSource(DataSource):
-    """Spark data source repesentation."""
-
-    def __init__(
-        self,
-        database: str,
-        query: str,
-        livy_url: str,
-        spark_config: Optional[Dict[str, str]] = None,
-        sample: float = 1.0,
-        batch_size: int = 100000000,
-    ):
-        """Spark data source properties initialization."""
-        self.database = database
-        self.query = query
-        self.livy_url = livy_url
-        self.spark_config = spark_config
-        self.sample = sample
-        self.batch_size = batch_size
-
-    @property
-    def _config(self) -> Dict[str, Any]:
-        return {
-            "database": self.database,
-            "query": self.query,
-            "livy_url": self.livy_url,
-            "spark_config": self.spark_config,
-            "sample": self.sample,
-            "batch_size": self.batch_size,
-        }
-
-
-class SparkSQLDataSource(SparkDataSource):
-    """Spark-SQL data source configuration."""
-
-    @property
-    def _type(self) -> str:
-        return "spark-sql"
-
-
-class BigQueryDataSource(SparkDataSource):
-    """BiqQuery data source configuration."""
-
-    @property
-    def _type(self) -> str:
-        return "bigquery"
+DEFAULT_CONNECTION_TIMEOUT_SECONDS = 60 * 10
 
 
 def _get_query_data(
@@ -79,7 +19,7 @@ def _get_query_data(
 ) -> Dict[str, Any]:
     data = {
         "name": dataset,
-        "data_source": {"type": data_source._type, "config": data_source._config},
+        "data_source": data_source.serialize(),
         "sync": {
             "enabled": True,
             "environment": environment,
@@ -116,6 +56,7 @@ async def connect_dataset(
     features: Optional[Dict[str, str]] = None,
     labels: Optional[Dict[str, str]] = None,
     raw_inputs: Optional[Dict[str, str]] = None,
+    http_timeout_seconds: Optional[int] = None,
 ):
     """Connect to a dataset.
 
@@ -132,7 +73,14 @@ async def connect_dataset(
         features: Features -> columns mappping. Defaults to None.
         labels: Labels -> columns mappping. Defaults to None.
         raw_inputs: Raw inputs -> columns mappping. Defaults to None.
+        http_timeout_seconds: HTTP timeout in seconds. Defaults to 10 minutes.
     """
+    http_timeout_seconds = (
+        http_timeout_seconds
+        if http_timeout_seconds is not None
+        else DEFAULT_CONNECTION_TIMEOUT_SECONDS
+    )
+
     await http_client.post(
         url=f"/models/{model_id}/versions/{model_version}/datasets",
         data=_get_query_data(
@@ -146,5 +94,5 @@ async def connect_dataset(
             labels=labels,
             raw_inputs=raw_inputs,
         ),
-        timeout=60 * 10,
+        timeout=http_timeout_seconds,
     )
