@@ -10,8 +10,9 @@ from numpy import ndarray
 from aporia.core.base_model import BaseModel, validate_model_ready
 from aporia.core.errors import handle_error
 from aporia.core.logging_utils import LOGGER_NAME
+from aporia.core.types.data_source import DataSource
 from aporia.core.types.field import FieldValue
-from aporia.inference.api.dataset import connect_dataset, DataSource
+from aporia.inference.api.dataset import connect_dataset
 from aporia.inference.api.log_model_properties import (
     log_index_to_word_mapping,
     set_feature_importance,
@@ -340,6 +341,7 @@ class InferenceModel(BaseModel):
         features: Optional[Dict[str, str]] = None,
         labels: Optional[Dict[str, str]] = None,
         raw_inputs: Optional[Dict[str, str]] = None,
+        http_timeout_seconds: Optional[int] = None,
     ):
         """Connect to external serving data set.
 
@@ -351,6 +353,7 @@ class InferenceModel(BaseModel):
             predictions: Mapping from prediction name to column name.
             labels: Mapping from actual name to column name.
             raw_inputs: Mapping from raw input name to column name.
+            http_timeout_seconds: HTTP timeout in seconds. Defaults to 10 minutes.
         """
         with self.handle_error("Connection to serving failed, error: {}"):
             self._event_loop.run_coroutine(
@@ -367,6 +370,41 @@ class InferenceModel(BaseModel):
                     predictions=predictions,
                     labels=labels,
                     raw_inputs=raw_inputs,
+                    http_timeout_seconds=http_timeout_seconds,
+                )
+            )
+
+    @validate_model_ready
+    def connect_actuals(
+        self,
+        data_source: DataSource,
+        id_column: str,
+        timestamp_column: str,
+        labels: Optional[Dict[str, str]] = None,
+        http_timeout_seconds: Optional[int] = None,
+    ):
+        """Connect to external actual data set.
+
+        Args:
+            data_source: The data source to fetch the data set from.
+            id_column: The name of the id column.
+            timestamp_column: The name of a column contains the times actual was updated.
+            labels: Mapping from the predictions name to column holding the actual value.
+            http_timeout_seconds: HTTP timeout in seconds. Defaults to 10 minutes.
+        """
+        with self.handle_error("Connection to actuals failed, error: {}"):
+            self._event_loop.run_coroutine(
+                connect_dataset(
+                    http_client=self._http_client,
+                    model_id=self.model_id,
+                    model_version=self.model_version,
+                    environment=self._config.environment,
+                    dataset="actuals",
+                    data_source=data_source,
+                    id_column=id_column,
+                    timestamp_column=timestamp_column,
+                    labels=labels,
+                    http_timeout_seconds=http_timeout_seconds,
                 )
             )
 
@@ -380,6 +418,7 @@ class InferenceModel(BaseModel):
         features: Optional[Dict[str, str]] = None,
         labels: Optional[Dict[str, str]] = None,
         raw_inputs: Optional[Dict[str, str]] = None,
+        http_timeout_seconds: Optional[int] = None,
     ):
         """Connect to external training data set.
 
@@ -391,6 +430,7 @@ class InferenceModel(BaseModel):
             predictions: Mapping from prediction name to column name.
             labels: Mapping from prediction name to column name.
             raw_inputs: Mapping from raw input name to column name.
+            http_timeout_seconds: HTTP timeout in seconds. Defaults to 10 minutes.
         """
         with self.handle_error("Connection to training set failed, error: {}"):
             self._event_loop.run_coroutine(
@@ -407,6 +447,7 @@ class InferenceModel(BaseModel):
                     predictions=predictions,
                     labels=labels,
                     raw_inputs=raw_inputs,
+                    http_timeout_seconds=http_timeout_seconds,
                 )
             )
 
@@ -420,6 +461,7 @@ class InferenceModel(BaseModel):
         features: Optional[Dict[str, str]] = None,
         labels: Optional[Dict[str, str]] = None,
         raw_inputs: Optional[Dict[str, str]] = None,
+        http_timeout_seconds: Optional[int] = None,
     ):
         """Connect to external test data set.
 
@@ -431,6 +473,7 @@ class InferenceModel(BaseModel):
             predictions: Mapping from prediction name to column name.
             labels: Mapping from prediction name to column name.
             raw_inputs: Mapping from raw input name to column name.
+            http_timeout_seconds: HTTP timeout in seconds. Defaults to 10 minutes.
         """
         with self.handle_error("Connection to test set failed, error: {}"):
             self._event_loop.run_coroutine(
@@ -447,6 +490,7 @@ class InferenceModel(BaseModel):
                     predictions=predictions,
                     labels=labels,
                     raw_inputs=raw_inputs,
+                    http_timeout_seconds=http_timeout_seconds,
                 )
             )
 
