@@ -8,6 +8,7 @@ try:
     import pandas
 
     import aporia.training
+    from aporia.training.training_model import SAMPLE_SIZE
 
     ndarray = numpy.ndarray
     DataFrame = pandas.DataFrame
@@ -17,6 +18,7 @@ except ImportError:
     ndarray = Any  # type: ignore
     DataFrame = Any
     TRAINING_ENABLED = False
+    SAMPLE_SIZE = 1000
 
 try:
     import numpy
@@ -83,21 +85,26 @@ class Model(InferenceModel):
     def log_training_set(
         self,
         features: Union[DataFrame, ndarray],  # type: ignore
+        predictions: Optional[DataFrame] = None,  # type: ignore
         labels: Optional[DataFrame] = None,  # type: ignore
         raw_inputs: Optional[DataFrame] = None,  # type: ignore
-        sample: bool = True,
+        log_sample: bool = True,
+        sample_size: int = SAMPLE_SIZE,
     ):
         """Logs aggregations of the whole set and logs a sample of the data.
 
         Args:
             features: Training set features
+            predictions: Training set predictions
             labels: Training set labels
             raw_inputs: Training set raw inputs.
-            sample: Whether to log a sample of the data.
+            log_sample: Whether to log a sample of the data.
+            sample_size: Number of records to sample.
 
         Notes:
             * Each dataframe corresponds to a field category defined in create_model_version:
                 * features -> features
+                * predictions -> predictions
                 * labels -> predictions
                 * raw_inputs -> raw_inputs
             * Each column in the dataframe should match a field defined in create_model_version
@@ -118,9 +125,11 @@ class Model(InferenceModel):
 
             self._training.log_training_set(
                 features=features,
+                predictions=predictions,
                 labels=labels,
                 raw_inputs=raw_inputs,
-                sample=sample,
+                log_sample=log_sample,
+                sample_size=sample_size,
             )
 
     def log_training_sample(
@@ -128,6 +137,7 @@ class Model(InferenceModel):
         features: Union[DataFrame, ndarray],  # type: ignore
         labels: DataFrame,  # type: ignore
         raw_inputs: Optional[DataFrame] = None,  # type: ignore
+        sample_size: int = SAMPLE_SIZE,
     ):
         """Logs a sample of the training data.
 
@@ -135,6 +145,7 @@ class Model(InferenceModel):
             features: Training set features
             labels: Training set labels
             raw_inputs: Training set raw_inputs
+            sample_size: Number of records to sample
 
         Notes:
             * Each dataframe corresponds to a field category defined in create_model_version:
@@ -157,7 +168,7 @@ class Model(InferenceModel):
                 )
 
             self._training.log_training_data(
-                features=features, labels=labels, raw_inputs=raw_inputs
+                features=features, labels=labels, raw_inputs=raw_inputs, sample_size=sample_size
             )
 
     def log_test_set(
@@ -314,6 +325,63 @@ class Model(InferenceModel):
                 spark_options=spark_options,
             )
 
+    def log_streaming_pyspark_prediction(
+        self,
+        data: PySparkDataFrame,
+        id_column: Optional[str] = None,
+        timestamp_column: Optional[str] = None,
+        features: Optional[Mapping[str, str]] = None,
+        predictions: Optional[Mapping[str, str]] = None,
+        raw_inputs: Optional[Mapping[str, str]] = None,
+        labels: Optional[Mapping[str, str]] = None,
+        spark_options: Optional[Mapping[str, str]] = None,
+        date_format: Optional[str] = None,
+    ):
+        """Logs stream of predictions.
+
+        Args:
+            data: PsSpark dataframe
+            id_column: Optional dataframe column to use as an id.
+            timestamp_column: Optional dataframe column to use as an id.
+            features: A mapping of feature names (from the schema) to dataframe columns
+            predictions: A mapping of predictions names (from the schema) to dataframe columns
+            raw_inputs: A mapping of raw input names (from the schema) to dataframe columns
+            labels: A mapping of label names (from the schema) to dataframe columns
+            spark_options: Optional configuration extension for spark elastic connector. See
+                https://www.elastic.co/guide/en/elasticsearch/hadoop/master/configuration.html
+            date_format: Date format for indexing
+        """
+        with self.handle_error("{}"):
+            if self._pyspark_inference is None:
+                raise AporiaError(
+                    short_message="Logging pyspark predictions failed, Aporia pyspark extension not found",
+                    verbose_message=(
+                        "The Aporia pyspark extension is required to log predictions from pyspark "
+                        "dataframes. Install it with `pip install aporia[pyspark] and try again."
+                    ),
+                )
+            from aporia.experimental.model_versions_api import get_model_versions
+
+            version_id = next(
+                version.id
+                for version in get_model_versions(self.model_id)
+                if version.name == self.model_version
+            )
+
+            self._pyspark_inference.log_streaming_pyspark_prediction(
+                version_id=version_id,
+                model=self,
+                data=data,
+                id_column=id_column,
+                features=features,
+                predictions=predictions,
+                timestamp_column=timestamp_column,
+                raw_inputs=raw_inputs,
+                labels=labels,
+                spark_options=spark_options,
+                date_format=date_format,
+            )
+
     def log_pyspark_training_set(
         self,
         data: PySparkDataFrame,
