@@ -1,24 +1,31 @@
 from collections import abc, OrderedDict
-from typing import Dict, Optional, Union
+from typing import Any, Dict, Iterable, Optional, Union
 
 import numpy as np
 import pandas as pd
 
 from aporia.core.context import get_context
 from aporia.core.errors import AporiaError, handle_error
-from aporia.core.types.field import FieldType, FieldValue
+from aporia.core.types.field import FieldSchema, FieldType, FieldValue
+
+
+def _dtype_to_field_type(dtype: str) -> Optional[FieldSchema]:
+    # This is based on https://numpy.org/doc/stable/reference/generated/numpy.dtype.kind.html#numpy.dtype.kind
+    DTYPE_TO_FIELD_TYPE = {
+        "b": FieldType.BOOLEAN,
+        "i": FieldType.NUMERIC,
+        "u": FieldType.NUMERIC,
+        "f": FieldType.NUMERIC,
+        "M": FieldType.DATETIME,
+        "O": FieldType.STRING,
+        "S": FieldType.STRING,
+        "U": FieldType.STRING,
+    }
+    field_type = DTYPE_TO_FIELD_TYPE.get(dtype)
+    if field_type is None:
+        return None
+    return {"type": field_type.value}
 
-# This is based on https://numpy.org/doc/stable/reference/generated/numpy.dtype.kind.html#numpy.dtype.kind
-DTYPE_TO_FIELD_TYPE = {
-    "b": FieldType.BOOLEAN,
-    "i": FieldType.NUMERIC,
-    "u": FieldType.NUMERIC,
-    "f": FieldType.NUMERIC,
-    "M": FieldType.DATETIME,
-    "O": FieldType.STRING,
-    "S": FieldType.STRING,
-    "U": FieldType.STRING,
-}
 
 NUMERIC_DTYPES = ["i", "u", "f"]
 STRING_DTYPES = ["O", "S", "U"]
@@ -26,7 +33,7 @@ STRING_UNIQUE_RATIO = 0.25
 MIN_UNIQUE_VALUES_FOR_TEXT = 50
 
 
-def _infer_string_data_for_text_or_string(data: pd.Series) -> FieldType:
+def _infer_string_data_for_text_or_string(data: pd.Series) -> FieldSchema:
     """Convert a numpy/pandas of series contains only strings to a FieldType.
 
     Args:
@@ -41,9 +48,9 @@ def _infer_string_data_for_text_or_string(data: pd.Series) -> FieldType:
     _, unique_counts = np.unique(data.values, return_counts=True)
     uniques = len(unique_counts)
     if uniques > MIN_UNIQUE_VALUES_FOR_TEXT and uniques > data.shape[0] * STRING_UNIQUE_RATIO:
-        return FieldType.TEXT
+        return {"type": FieldType.TEXT.value}
 
-    return FieldType.STRING
+    return {"type": FieldType.STRING.value}
 
 
 def _replace_na_type(data: pd.Series) -> pd.Series:
@@ -64,7 +71,7 @@ def _replace_na_type(data: pd.Series) -> pd.Series:
     return result
 
 
-def _infer_object_dtype_column(data: pd.Series) -> Optional[FieldType]:
+def _infer_object_dtype_column(data: pd.Series) -> Optional[FieldSchema]:
     """Attempts to convert a numpy/pandas series of object dtype to a FieldType.
 
     Args:
@@ -76,16 +83,17 @@ def _infer_object_dtype_column(data: pd.Series) -> Optional[FieldType]:
     if data.size == 0:
         return None
     elif data.apply(lambda x: isinstance(x, dict)).all():
-        return FieldType.DICT
+        return {"type": FieldType.DICT.value}
     elif data.apply(lambda x: isinstance(x, str)).all():
         return _infer_string_data_for_text_or_string(data=data)
-
+    elif data.apply(lambda x: isinstance(x, abc.Iterable)).all():
+        return {"type": FieldType.TENSOR.value, "dimensions": [len(data.values[0])]}
     return None
 
 
-def infer_type_from_dtype_and_data(
+def infer_field_schema_from_dtype_and_data(
     dtype: np.dtype, data: Optional[pd.Series]
-) -> Optional[FieldType]:
+) -> Optional[FieldSchema]:
     """Attempts to convert a numpy/pandas dtype to a FieldType.
 
     Args:
@@ -96,10 +104,12 @@ def infer_type_from_dtype_and_data(
         FieldType that matches the dtype, or None if conversion is impossible
     """
     if isinstance(dtype, pd.api.types.CategoricalDtype):
-        category_type = DTYPE_TO_FIELD_TYPE.get(dtype.categories.dtype.kind)
+        category_type = _dtype_to_field_type(dtype.categories.dtype.kind)
         # We only support categorical fields with numeric categories
-        if category_type == FieldType.NUMERIC:
-            return FieldType.CATEGORICAL
+        if category_type is None:
+            return None
+        if category_type["type"] == FieldType.NUMERIC.value:
+            return {"type": FieldType.CATEGORICAL.value}
 
         return category_type
 
@@ -108,15 +118,17 @@ def infer_type_from_dtype_and_data(
 
     if data is not None and not data.empty:
         if dtype.kind in NUMERIC_DTYPES and isinstance(data.values[0], abc.Iterable):
-            return FieldType.VECTOR
+            arr: Any = data.values[0]
+            return {"type": FieldType.TENSOR.value, "dimensions": [len(arr)]}
 
         # We need to decided if a string type is str or text
         # We check if there are more than 50 unique values
         # which are more than 25% of the total values
         if dtype.kind in STRING_DTYPES and len(data.shape) > 0:
+
             return _infer_string_data_for_text_or_string(data=data)
 
-    return DTYPE_TO_FIELD_TYPE.get(dtype.kind)  # type: ignore
+    return _dtype_to_field_type(dtype.kind)  # type: ignore
 
 
 def pandas_to_dict(data: Union[pd.DataFrame, pd.Series]) -> Optional[Dict[str, FieldValue]]:
@@ -159,7 +171,7 @@ def pandas_to_dict(data: Union[pd.DataFrame, pd.Series]) -> Optional[Dict[str, F
     return None
 
 
-def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
+def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, Dict]]:
     """Infers model version schema from a pandas DataFrame or Series.
 
     Field names and types are inferred from column names and types.
@@ -195,13 +207,13 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
         values_without_nulls = _replace_na_type(values)
         values_without_nulls = values_without_nulls.dropna().infer_objects()
 
-        column_type = infer_type_from_dtype_and_data(
+        column_type = infer_field_schema_from_dtype_and_data(
             values_without_nulls.dtype, values_without_nulls
         )
         if column_type is None:
             not_inferable_columns.append(column_name)
         else:
-            schema[column_name] = column_type.value
+            schema[column_name] = column_type
 
     if len(not_inferable_columns) > 0:
         raise AporiaError(
@@ -211,3 +223,16 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
         )
 
     return schema
+
+
+def create_null_dataframe(size: int, columns: Iterable[str]) -> pd.DataFrame:
+    """Creates a dataframe with nulls for each column.
+
+    Args:
+        size: Number of rows to create.
+        columns: Iterable of column names.
+
+    Returns:
+        Dataframe with nulls for each column.
+    """
+    return pd.DataFrame({column: [None for _ in range(size)] for column in columns})
