@@ -6,7 +6,7 @@ from pyspark.sql.types import Row
 
 from aporia.core.errors import AporiaError
 from aporia.inference.inference_model import InferenceModel
-from aporia.pyspark.experimental.batch_api import log_batch_prediction
+from aporia.pyspark.experimental.batch_api import log_batch_prediction, log_streaming_prediction
 
 
 class PySparkPrediction:
@@ -93,6 +93,7 @@ class PySparkInferenceModel:
         raw_inputs: Optional[Mapping[str, str]] = None,
         labels: Optional[Mapping[str, str]] = None,
         spark_options: Optional[Mapping[str, str]] = None,
+        date_format: Optional[str] = None,
     ):
         """See aporia.model.Model."""
         with self._inference_model.handle_error(
@@ -109,6 +110,39 @@ class PySparkInferenceModel:
                 raw_inputs=raw_inputs,
                 labels=labels,
                 spark_options=spark_options,
+                date_format=date_format,
+            )
+
+    def log_streaming_pyspark_prediction(
+        self,
+        version_id: str,
+        data: DataFrame,
+        model: Any,
+        id_column: Optional[str] = None,
+        features: Optional[Mapping[str, str]] = None,
+        predictions: Optional[Mapping[str, str]] = None,
+        timestamp_column: Optional[str] = None,
+        raw_inputs: Optional[Mapping[str, str]] = None,
+        labels: Optional[Mapping[str, str]] = None,
+        spark_options: Optional[Mapping[str, str]] = None,
+        date_format: Optional[str] = None,
+    ):
+        """See aporia.model.Model."""
+        with self._inference_model.handle_error(
+            "Logging PySpark prediction batch failed, error: {}"
+        ):
+            log_streaming_prediction(
+                version_id=version_id,
+                apr_model=model,
+                data=data,
+                id_column=id_column,
+                features=features,
+                predictions=predictions,
+                timestamp_column=timestamp_column,
+                raw_inputs=raw_inputs,
+                labels=labels,
+                spark_options=spark_options,
+                date_format=date_format,
             )
 
     @staticmethod
