@@ -9,6 +9,7 @@ from aporia.core.base_model import BaseModel, validate_model_ready
 from aporia.core.logging_utils import LOGGER_NAME
 from aporia.core.types.field import FieldCategory, FieldType
 from aporia.core.utils import generate_features_schema_from_shape
+from aporia.pandas.pandas_utils import create_null_dataframe
 from .api.get_model_version import get_model_version
 from .api.log_training import (
     FieldTrainingData,
@@ -44,9 +45,11 @@ class TrainingModel(BaseModel):
     def log_training_set(
         self,
         features: Union[DataFrame, ndarray],
+        predictions: Optional[DataFrame] = None,
         labels: Optional[DataFrame] = None,
         raw_inputs: Optional[DataFrame] = None,
-        sample: bool = True,
+        log_sample: bool = True,
+        sample_size: int = SAMPLE_SIZE,
     ):
         """See aporia.model.Model."""
         logger.debug("Logging training set.")
@@ -55,7 +58,9 @@ class TrainingModel(BaseModel):
             validator = TrainingValidator(
                 dataset_type=TrainingDataset.TRAINING, schema=version_schema
             )
-            validator.validate(features=features, labels=labels, raw_inputs=raw_inputs)
+            validator.validate(
+                features=features, predictions=predictions, labels=labels, raw_inputs=raw_inputs
+            )
 
             raw_inputs_training_data = None
             if raw_inputs is not None:
@@ -63,12 +68,24 @@ class TrainingModel(BaseModel):
                     raw_inputs, version_schema[FieldCategory.RAW_INPUTS]
                 )
 
-            labels_training_data = None
-            if labels is not None:
-                labels_training_data = calculate_dataframe_training_data(
-                    labels, version_schema[FieldCategory.PREDICTIONS]
+            if labels is None:
+                labels = create_null_dataframe(
+                    size=len(features), columns=version_schema[FieldCategory.PREDICTIONS].keys()
                 )
 
+            labels_training_data = calculate_dataframe_training_data(
+                labels, version_schema[FieldCategory.PREDICTIONS]
+            )
+
+            if predictions is None:
+                predictions = create_null_dataframe(
+                    size=len(features), columns=version_schema[FieldCategory.PREDICTIONS].keys()
+                )
+
+            predictions_training_data = calculate_dataframe_training_data(
+                predictions, version_schema[FieldCategory.PREDICTIONS], labels
+            )
+
             if isinstance(features, DataFrame):
                 features_dataframe = features
                 features_schema = version_schema[FieldCategory.FEATURES]
@@ -77,14 +94,17 @@ class TrainingModel(BaseModel):
                     features=features
                 )
 
-            self.log_training_data(
-                features=features_dataframe,
-                labels=labels,
-                raw_inputs=raw_inputs,
-                sample=sample,
-            )
+            if log_sample:
+                self.log_training_data(
+                    features=features_dataframe,
+                    labels=labels,
+                    raw_inputs=raw_inputs,
+                    sample_size=sample_size,
+                )
+
             self.log_training_set_aggregations(
                 features=calculate_dataframe_training_data(features_dataframe, features_schema),
+                predictions=predictions_training_data,
                 labels=labels_training_data,
                 raw_inputs=raw_inputs_training_data,
             )
@@ -124,7 +144,7 @@ class TrainingModel(BaseModel):
             self.log_test_set_aggregations(
                 features=calculate_dataframe_training_data(features_dataframe, features_schema),
                 predictions=calculate_dataframe_training_data(
-                    predictions, version_schema[FieldCategory.PREDICTIONS]
+                    predictions, version_schema[FieldCategory.PREDICTIONS], labels
                 ),
                 labels=calculate_dataframe_training_data(
                     labels, version_schema[FieldCategory.PREDICTIONS]
@@ -136,6 +156,7 @@ class TrainingModel(BaseModel):
     def log_training_set_aggregations(
         self,
         features: List[FieldTrainingData],
+        predictions: Optional[List[FieldTrainingData]] = None,
         labels: Optional[List[FieldTrainingData]] = None,
         raw_inputs: Optional[List[FieldTrainingData]] = None,
     ):
@@ -143,7 +164,8 @@ class TrainingModel(BaseModel):
 
         Args:
             features: Feature field aggregations
-            labels: Label (prediction) field aggregations
+            predictions: Prediction field aggregations
+            labels: Label (actual) field aggregations
             raw_inputs: Raw Inputs aggregations
         """
         self._event_loop.run_coroutine(
@@ -152,6 +174,7 @@ class TrainingModel(BaseModel):
                 model_id=self.model_id,
                 model_version=self.model_version,
                 features=features,
+                predictions=predictions,
                 labels=labels,
                 raw_inputs=raw_inputs,
             )
@@ -191,36 +214,31 @@ class TrainingModel(BaseModel):
         features: Union[DataFrame, ndarray],
         labels: Optional[DataFrame] = None,
         raw_inputs: Optional[DataFrame] = None,
-        sample: Optional[bool] = True,
+        sample_size: int = SAMPLE_SIZE,
     ):
-        """Logs training data.
+        """Logs a sample of the training data.
 
         Args:
             features: Training set features
             labels: Training set labels
             raw_inputs: Training set raw inputs
-            sample: Should we report all data or just a sample
-
-        Notes:
-            * As this is a sample for analytical purpose, we log a maximum of 1000 rows.
+            sample_size: Number of records to sample
         """
-        report_size = SAMPLE_SIZE if sample else MAX_LIMIT
-
         if isinstance(features, ndarray):
             features, _ = self._build_features_dataframe_and_schema(features)
 
         # Null values are replaced with np.nan, because orjson can't serialize pd.NA
         features_sample = cast(
-            DataFrame, features.sample(min(report_size, len(features))).fillna(nan)
+            DataFrame, features.sample(min(sample_size, len(features))).fillna(nan)
         )
         if labels is not None:
             labels_sample = cast(
-                DataFrame, labels.sample(min(report_size, len(labels))).fillna(nan)
+                DataFrame, labels.sample(min(sample_size, len(labels))).fillna(nan)
             )
 
         if raw_inputs is not None:
             raw_inputs_sample = cast(
-                DataFrame, raw_inputs.sample(min(report_size, len(raw_inputs))).fillna(nan)
+                DataFrame, raw_inputs.sample(min(sample_size, len(raw_inputs))).fillna(nan)
             )
 
         self._event_loop.run_coroutine(
